VineSameAsRule class final

Implemented types

Constructors

VineSameAsRule(String value, String? message)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

handle(VineValidationContext<VineErrorReporter> ctx, VineFieldContext field) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited